==> classicperipherals-0.2.1-fabric-1.21.1-sources.jar: me/alexdevs/classicPeripherals/block/ModBlocks.java <==
package me.alexdevs.classicPeripherals.block;

import me.alexdevs.classicPeripherals.ClassicPeripherals;
import me.alexdevs.classicPeripherals.block.antenna.AntennaBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerBaseBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerHeadBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerSegmentBlock;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3620;
import net.minecraft.class_4970;
import net.minecraft.class_7923;

public class ModBlocks {
    public static final TowerBaseBlock TOWER_BASE = register("tower_base", new TowerBaseBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final TowerSegmentBlock TOWER_SEGMENT = register("tower_segment", new TowerSegmentBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final TowerHeadBlock TOWER_HEAD = register("tower_head", new TowerHeadBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_15994)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final AntennaBlock ANTENNA = register("antenna", new AntennaBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_15994)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final NfcReaderBlock NFC_READER = register("nfc_reader", new NfcReaderBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
    ), true);

    public static final RfidScannerBlock RFID_SCANNER = register("rfid_scanner", new RfidScannerBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
    ), true);

    public static <T extends class_2248> T register(String name, T block, boolean shouldRegisterItem) {
        class_2960 id = class_2960.method_60655(ClassicPeripherals.MOD_ID, name);

        if (shouldRegisterItem) {
            class_1747 blockItem = new class_1747(block, new class_1792.class_1793());
            class_2378.method_10230(class_7923.field_41178, id, (class_1792)blockItem);
        }

        return class_2378.method_10230(class_7923.field_41175, id, block);
    }

    public static void initialize() {
    }
}

==> classicperipherals-0.2.3-fabric-1.20.1-sources.jar: me/alexdevs/classicPeripherals/block/ModBlocks.java <==
package me.alexdevs.classicPeripherals.block;

import me.alexdevs.classicPeripherals.ClassicPeripherals;
import me.alexdevs.classicPeripherals.block.antenna.AntennaBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerBaseBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerHeadBlock;
import me.alexdevs.classicPeripherals.block.tower.TowerSegmentBlock;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3620;
import net.minecraft.class_4970;
import net.minecraft.class_7923;

public class ModBlocks {
    public static final TowerBaseBlock TOWER_BASE = register("tower_base", new TowerBaseBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final TowerSegmentBlock TOWER_SEGMENT = register("tower_segment", new TowerSegmentBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final TowerHeadBlock TOWER_HEAD = register("tower_head", new TowerHeadBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_15994)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final AntennaBlock ANTENNA = register("antenna", new AntennaBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_15994)
            .method_22488()
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
            .method_26243(class_2246::method_26122)
            .method_26245(class_2246::method_26122)
    ), true);

    public static final NfcReaderBlock NFC_READER = register("nfc_reader", new NfcReaderBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
    ), true);

    public static final RfidScannerBlock RFID_SCANNER = register("rfid_scanner", new RfidScannerBlock(class_4970.class_2251.method_9637()
            .method_9632(2.0F)
            .method_31710(class_3620.field_16023)
            .method_26235(class_2246::method_26114)
            .method_26236(class_2246::method_26122)
    ), true);

    public static <T extends class_2248> T register(String name, T block, boolean shouldRegisterItem) {
        class_2960 id = new class_2960(ClassicPeripherals.MOD_ID, name);

        if (shouldRegisterItem) {
            class_1747 blockItem = new class_1747(block, new class_1792.class_1793());
            class_2378.method_10230(class_7923.field_41178, id, (class_1792)blockItem);
        }

        return class_2378.method_10230(class_7923.field_41175, id, block);
    }

    public static void initialize() {
    }
}
